@@ -15,17 +15,12 @@ YESTERDAY_STR = YESTERDAY.strftime("%Y-%m-%d")
 FORTNIGHT_AGO = (datetime.datetime.now() - datetime.timedelta(days=14)).date()
 ONE_YEAR_AGO = (datetime.datetime.now() - datetime.timedelta(days=364)).date()
 
-DATA_FILE_LOCATION = f"{HOME_DIR}/.sylo/sessions.dat"
-TASK_FILE_LOCATION = f"{HOME_DIR}/.sylo/tasks.dat"
 CONFIG_FILE_LOCATION = f"{HOME_DIR}/.sylo/sylo.cfg"
-POMS_DATA_FILE_LOCATION = f"{HOME_DIR}/.sylo/poms.dat"
-
 HOME_DIR_CREATE = f"mkdir {HOME_DIR}/.sylo"
-DATA_FILE_CREATE = f'echo "{TODAY_STR},0,0" > {DATA_FILE_LOCATION}'
-TASK_FILE_CREATE = f"touch {TASK_FILE_LOCATION}"
-POMS_DATA_FILE_CREATE = f'echo "{TODAY_STR},0" > {POMS_DATA_FILE_LOCATION}'
+SYLO_HOME = f"{HOME_DIR}/.sylo"
 
-WELCOME_CHOICES = ("", "h", "q", "s", "i", "t", "y", "a")
+
+WELCOME_CHOICES = ("", "h", "q", "s", "t", "y", "i", "a")
 
 TIMER_DEFAULTS = {
     "work": {
@@ -44,4 +39,9 @@ METRICS_HEAT = 'termgraph --calendar --color magenta --start-dt "%s" %s 2>/dev/n
 
 METRICS_BAR = 'termgraph %s --color {red,green} --start-dt "%s" 2>/dev/null'
 
-POMS_METRICS_BAR = 'termgraph %s --color magenta --start-dt "%s" 2>/dev/null'
+SQLITE_DB = f"{HOME_DIR}/.sylo/_sylo.db"
+
+BOOTSTRAP_SQL = f"{ROOT_DIR}/database_interactions/bootstrap.sql"
+
+INSIGHTS_FILE_SESSIONS = f"{HOME_DIR}/.sylo/insights_sessions.dat"
+INSIGHTS_FILE_POMS = f"{HOME_DIR}/.sylo/insights_poms.dat"
