@@ -1,6 +1,6 @@
 from pyfiglet import figlet_format
 from typing import List
-from colorama import Fore, Style, Back
+from colorama import Fore, Style
 import sys
 import logging
 from sylo.models import Durations, Config
@@ -28,8 +28,8 @@ class Display:
         else:
             return f"{self.theme}{string}{Style.RESET_ALL}"
 
-    def print_poms(self, string: str):
-        return f"{self.col(Back.LIGHTMAGENTA_EX + string + ' ' + self.add_plurality(self.pom_name), 'white')}"
+    def print_poms(self, pom: int):
+        return f"{self.col(str(pom) + ' ' + self.add_plurality(self.pom_name), 'lmagenta')}"
 
     def print_timer(self, mode: str, timer_val: int, tasks: List = None):
         if mode == "work":
@@ -73,11 +73,6 @@ class Display:
             f"{self.col('Daily work/rest minutes, for the past fortnight', 'yellow')}"
         )
 
-    def print_poms_bar_header(self):
-        print(
-            f"\n{self.col(f'Weekly {self.add_plurality(self.pom_name)}, for the past fortnight', 'yellow')}"
-        )
-
     def print_heat_header(self):
         print(f"{self.col(f'{self.add_plurality(self.pom_name)} heatmap', 'yellow')}")
 
@@ -115,6 +110,8 @@ class Display:
             f"{self.col('to add a new task')}"
             f"\n{self.col('Press')} {self.col('C', 'yellow')} "
             f"{self.col('to toggle completion of a task')}"
+            f"\n{self.col('Press')} {self.col('M', 'yellow')} "
+            f"{self.col('to move task to today')}"
             f"\n{self.col('Press')} {self.col('D', 'yellow')} "
             f"{self.col('to delete a task')}"
         )
@@ -138,7 +135,7 @@ class Display:
     def print_splash(self, durations: Durations, mode: str):
         print(
             f"\nTotal {self.add_plurality(self.pom_name)} today:{self.fix_indent()}      "
-            f"{self.print_poms(str(int(durations.poms)))}"
+            f"{self.print_poms(int(durations.poms))}"
             f"\nUpcoming timer:     "
             f"        {self.col(mode.upper(), self._set_mode_color(mode, durations))}"
             f"\n"
@@ -177,7 +174,7 @@ class Display:
                 "\n".join(
                     "".join(map(str, f"{self.trim_string(self.col(t[2],'green'),45)}"))
                     for t in tasks
-                    if t[4] == "1"
+                    if t[4] == True
                 )
             )
             print("\n")
@@ -188,7 +185,7 @@ class Display:
                         map(str, f"\n{self.print_poms(t[3])}: " f"{tr.fill(t[2], 45)}")
                     )
                     for t in tasks
-                    if t[4] == "0"
+                    if t[4] == False
                 )
             )
             print("\n")
@@ -206,7 +203,7 @@ class Display:
                         )
                     )
                     for t in tasks
-                    if t[4] == "1"
+                    if t[4] == True
                 )
             )
             print("\n")
@@ -222,7 +219,7 @@ class Display:
                         )
                     )
                     for t in tasks
-                    if t[4] == "0"
+                    if t[4] == False
                 )
             )
             print("\n")
