@@ -3,37 +3,29 @@ import sys
 import logging
 import time
 import simpleaudio
+import csv
 from beepy import beep
 from tqdm import tqdm
 from colorama import Fore
 from typing import List
-import csv
 from sylo.models import (
     Durations,
-    DataPersistence,
-    get_tasks,
+    Database,
     ConfigFile,
-    get_max_id_in_csv,
-    complete_task,
-    remove_task,
 )
 from sylo.definitions import (
-    TASK_FILE_LOCATION,
     TODAY_STR,
     YESTERDAY_STR,
     WELCOME_CHOICES,
     COUNTDOWN_INCREMENTS,
-    DATA_FILE_LOCATION,
     METRICS_BAR,
     METRICS_HEAT,
-    POMS_METRICS_BAR,
-    DATA_FILE_CREATE,
-    TASK_FILE_CREATE,
     HOME_DIR_CREATE,
     FORTNIGHT_AGO,
     ONE_YEAR_AGO,
-    POMS_DATA_FILE_CREATE,
-    POMS_DATA_FILE_LOCATION,
+    SYLO_HOME,
+    INSIGHTS_FILE_SESSIONS,
+    INSIGHTS_FILE_POMS,
 )
 from sylo.utils import (
     clear_screen,
@@ -41,7 +33,7 @@ from sylo.utils import (
     flip_mode,
     get_input,
     run_subprocess,
-    check_for_file,
+    check_for_dir,
 )
 from sylo.display import Display
 
@@ -50,7 +42,7 @@ logger = logging.getLogger(__name__)
 display = Display()
 is_speed_mode = False
 timer_mode = "work"
-data_file = DataPersistence()
+database = Database()
 cursor = display.cursor()
 initial_boot_flag = False
 
@@ -61,7 +53,16 @@ class Timer:
         self.mode: str = mode
         self.increments = increments
         self.mins_passed = 0
-        self.tasks = get_tasks(TODAY_STR)
+        self.tasks = database.select(
+            f"SELECT"
+            f'"id",'
+            f'"task_date",'
+            f'"description",'
+            f'"effort",'
+            f'"complete"'
+            f"FROM tasks WHERE \"task_date\" = '{TODAY_STR}' "
+            f";"
+        )
 
         if self.mode == "work":
             self.mins = self.durations.work.mins
@@ -143,11 +144,34 @@ class Sound:
 
 class Insights:
     def __init__(self):
-        self.data_file = DATA_FILE_LOCATION
-        self.poms_file = POMS_DATA_FILE_LOCATION
+        self.data_file = INSIGHTS_FILE_SESSIONS
+        self.poms_file = INSIGHTS_FILE_POMS
         self.heatmap_start_date = ONE_YEAR_AGO
         self.bar_start_date = FORTNIGHT_AGO
 
+    def save_files(self):
+        csv_writer = csv.writer(open(self.data_file, "w"))
+        data = database.select(
+            f""
+            f"SELECT * "
+            f"FROM sessions "
+            f"WHERE session_date >= {self.bar_start_date}"
+        )
+        logger.info(data)
+        for row in data:
+            csv_writer.writerow(row)
+
+        csv_writer = csv.writer(open(self.poms_file, "w"))
+        data = database.select(
+            f""
+            f"SELECT * "
+            f"FROM poms "
+            f"WHERE poms_date >= {self.heatmap_start_date}"
+        )
+        logger.info(data)
+        for row in data:
+            csv_writer.writerow(row)
+
     def print_bar(self):
         global initial_boot_flag
         display.print_header_small()
@@ -158,15 +182,6 @@ class Insights:
         else:
             print("No data available, complete some segments and check later.")
 
-    def print_poms(self):
-        global initial_boot_flag
-        display.print_poms_bar_header()
-        if initial_boot_flag is False:
-            logger.info(f"Running ${self._poms_bar_chart()}")
-            run_subprocess(self._poms_bar_chart())
-        else:
-            print("No data available, complete some segments and check later.")
-
     def print_heat(self):
         logger.info(f"Running ${self._heat_map()}")
         display.print_heat_header()
@@ -175,9 +190,6 @@ class Insights:
     def _bar_chart(self):
         return METRICS_BAR % (self.data_file, self.bar_start_date)
 
-    def _poms_bar_chart(self):
-        return POMS_METRICS_BAR % (self.poms_file, self.bar_start_date)
-
     def _heat_map(self):
         return METRICS_HEAT % (self.heatmap_start_date, self.poms_file)
 
@@ -189,19 +201,19 @@ class Task:
         self.complete = 0
         self.effort = 1
 
-    def write_task_to_file(self):
-        tasks = get_tasks()
-        max_id = get_max_id_in_csv(tasks)
-        fields = [
-            int(max_id) + 1,
-            self.date,
-            self.description,
-            self.effort,
-            self.complete,
-        ]
-        with open(TASK_FILE_LOCATION, "a") as f:
-            writer = csv.writer(f)
-            writer.writerow(fields)
+    def write_task_to_db(self):
+        database.execute(
+            f"INSERT INTO tasks ("
+            f'"task_date", '
+            f'"description", '
+            f'"effort", '
+            f'"complete"'
+            f") VALUES("
+            f'"{self.date}",'
+            f'"{self.description}",'
+            f'"{self.effort}",'
+            f'"{self.complete}");'
+        )
 
 
 class Sylo:
@@ -243,17 +255,21 @@ class Sylo:
             tasks=self.tasks,
         )
 
-    def task_menu(self, date: str = None):
-        self.show_tasks ^= True
-        self.tasks = get_tasks(date)
-        self.input_loop()
-
     def show_task(self, dates, with_id: bool = False):
         for date, day in zip(dates, ["YESTERDAY", "TODAY"]):
             print("\n")
             display.print_today_yesterday_tasks(day)
             print(display.col("-----------------------------------------\n"))
-            self.tasks = get_tasks(date)
+            self.tasks = database.select(
+                f"SELECT"
+                f'"id",'
+                f'"task_date",'
+                f'"description",'
+                f'"effort",'
+                f'"complete"'
+                f"FROM tasks WHERE \"task_date\" = '{date}'"
+                f";"
+            )
             if with_id is False:
                 display.print_tasks(self.tasks)
             else:
@@ -277,7 +293,7 @@ class Sylo:
                     "yellow",
                 )
             )
-            task.write_task_to_file()
+            task.write_task_to_db()
             self.edit_task_menu(dates)
         while usr_input.lower() == "c":
             clear_screen()
@@ -285,7 +301,22 @@ class Sylo:
             self.show_task(dates, True)
             display.print_edit_task()
             comp_input = input(display.col("Task id >> ", "yellow"))
-            complete_task(comp_input)
+            database.execute(
+                f'UPDATE tasks SET "complete" = '
+                f'CASE WHEN "complete" = False THEN True ELSE False END'
+                f' WHERE "id" = {comp_input};'
+            )
+            self.edit_task_menu(dates)
+        while usr_input.lower() == "m":
+            clear_screen()
+            display.print_header_small()
+            self.show_task(dates, True)
+            display.print_edit_task()
+            comp_input = input(display.col("Task id >> ", "yellow"))
+            database.execute(
+                f"UPDATE tasks SET \"task_date\" = '{TODAY_STR}'"
+                f' WHERE "id" = {comp_input};'
+            )
             self.edit_task_menu(dates)
         while usr_input.lower() == "d":
             clear_screen()
@@ -293,7 +324,7 @@ class Sylo:
             self.show_task(dates, True)
             display.print_remove_task()
             comp_input = input(display.col("Task id >> ", "yellow"))
-            remove_task(comp_input)
+            database.execute(f"DELETE FROM tasks" f' WHERE "id" = {comp_input};')
             self.edit_task_menu(dates)
         while usr_input.lower() not in ("", "n", "c"):
             self.edit_task_menu(dates)
@@ -311,9 +342,9 @@ class Sylo:
     def show_insights_menu(self):
         clear_screen()
         metrics = Insights()
+        metrics.save_files()
         metrics.print_bar()
         metrics.print_heat()
-        metrics.print_poms()
         display.print_insights(durations=self.durations)
         input(cursor)
         self.input_loop()
@@ -330,7 +361,14 @@ class Sylo:
             else:
                 self.durations.total_rest_mins += secs_passed
             self.mode = flip_mode(self.mode)
-            data_file.data_refresh(self.durations)
+            database.execute(
+                'INSERT INTO sessions ("session_date", "time_worked", "time_rested")'
+                f"VALUES ('{TODAY_STR}',"
+                f"'{self.durations.total_work_mins}', "
+                f"'{self.durations.total_rest_mins}')"
+                'ON CONFLICT ("session_date") DO UPDATE SET '
+                '("time_worked", "time_rested") = (excluded."time_worked", excluded."time_rested")'
+            )
             clear_screen()
         else:
             complete, secs_passed = timer.start_countdown()
@@ -341,7 +379,21 @@ class Sylo:
             else:
                 self.durations.total_work_mins += secs_passed
             self.mode = flip_mode(self.mode)
-            data_file.data_refresh(self.durations)
+            database.execute(
+                'INSERT INTO sessions ("session_date", "time_worked", "time_rested")'
+                f"VALUES ('{TODAY_STR}',"
+                f"'{self.durations.total_work_mins}', "
+                f"'{self.durations.total_rest_mins}')"
+                'ON CONFLICT ("session_date") DO UPDATE SET '
+                '("time_worked", "time_rested") = (excluded."time_worked", excluded."time_rested")'
+            )
+            database.execute(
+                'INSERT INTO poms ("poms_date", "poms")'
+                f"VALUES ('{TODAY_STR}',"
+                f"'{self.durations.poms}')"
+                'ON CONFLICT ("poms_date") DO UPDATE SET '
+                '"poms" = excluded."poms"'
+            )
             clear_screen()
         logger.info("Durations model set")
         logger.info(f"Work time: {self.durations.total_work_mins}")
@@ -388,11 +440,7 @@ def virgin_boostrap():
     global initial_boot_flag
     initial_boot_flag = True
     logger.info("First boot")
-    logger.info(f"No data file found, creating at {DATA_FILE_LOCATION}")
     run_subprocess(HOME_DIR_CREATE)
-    run_subprocess(DATA_FILE_CREATE)
-    run_subprocess(TASK_FILE_CREATE)
-    run_subprocess(POMS_DATA_FILE_CREATE)
 
 
 def config_allocation(args, config, durations: Durations):
@@ -423,10 +471,11 @@ def run(args, config):
     sound = Sound(config.audio_file)
     sound.initialise()
 
-    if check_for_file(DATA_FILE_LOCATION) is False:
+    if check_for_dir(SYLO_HOME) is False:
         virgin_boostrap()
     clear_screen()
-    data_file.data_load_on_boot(durations_data)
+    database.bootstrap_on_first_boot()
+    database.initial_data_load(durations_data)
 
     logger.info("Durations model set")
     logger.info(f"Work time:    {durations_data.work.mins}")
